function red=redkonv(metoda, primer)
% Funkcija redkonv(metoda, primer) odredjuje red konvergencije zadate
% metode za više koraka.
%
% Ulazni podaci:
% metoda - pokazivac na funkciju metode
% primer - ime skript fajla u kome su podaci o primeru koji zelimo
% testirati
%
% Izlayni podatak:
% red - red konvergencija (vektor vrednosti za različite korake)
% Test:
% red=redkonv(@ojler, 'primer1')
% za red konvergencije eksplicitne Adamsove metode reda 4, pozive je
% redkonv(@ (primer,h) AdamsE (primer,h,4), 'primer2.m')
% [y,x,err]=(primer,h) AdamsE (primer,h,4) definiše anonimnu funkciju
% sa dva ulazna argumenta, dok je treći fiksiran.
run(primer)
hm=(xm-x0); %maximalan korak
k=13;
h=hm./2.^(2:k); % koraci integracija za koje cemo testirati numericki red
err=zeros(1,k); % greske aproksimacija
for i=1:k-1
ya=metoda(primer, h(i)); %aproskimacija
x=x0:h(i):xm;
yt=ye(x); %tacno resenje
err(i)=max(abs(ya-yt)); %greska aproksimacije u maksimalnoj normi
end
red=log2(err(1:k-1)./err(2:k)); %red konvergencije

